==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/OfficeDataConnectorDataTypesExchangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DataTypeState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Exchange data type connection.
 * @property state Describe whether this data type connection is enabled or not.
 */
public data class OfficeDataConnectorDataTypesExchangeArgs(
    public val state: Output<Either<String, DataTypeState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs =
        com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [OfficeDataConnectorDataTypesExchangeArgs].
 */
@PulumiTagMarker
public class OfficeDataConnectorDataTypesExchangeArgsBuilder internal constructor() {
    private var state: Output<Either<String, DataTypeState>>? = null

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("hsiapiesbbtdyiks")
    public suspend fun state(`value`: Output<Either<String, DataTypeState>>) {
        this.state = value
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("kggvbuifgeldkbsv")
    public suspend fun state(`value`: Either<String, DataTypeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("tslalajnqsbrbkop")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("tmscmylqqhnxfeim")
    public fun state(`value`: DataTypeState) {
        val toBeMapped = Either.ofRight<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): OfficeDataConnectorDataTypesExchangeArgs =
        OfficeDataConnectorDataTypesExchangeArgs(
            state = state,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/OfficeDataConnectorDataTypesExchangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DataTypeState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Exchange data type connection.
 * @property state Describe whether this data type connection is enabled or not.
 */
public data class OfficeDataConnectorDataTypesExchangeArgs(
    public val state: Output<Either<String, DataTypeState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs =
        com.pulumi.azurenative.securityinsights.inputs.OfficeDataConnectorDataTypesExchangeArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [OfficeDataConnectorDataTypesExchangeArgs].
 */
@PulumiTagMarker
public class OfficeDataConnectorDataTypesExchangeArgsBuilder internal constructor() {
    private var state: Output<Either<String, DataTypeState>>? = null

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("duuxnxolcrogouys")
    public suspend fun state(`value`: Output<Either<String, DataTypeState>>) {
        this.state = value
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("kxtkrwymswoderph")
    public suspend fun state(`value`: Either<String, DataTypeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("oxhhvdpbyudlrlmp")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("qnfdrgrpnbkpqjxp")
    public fun state(`value`: DataTypeState) {
        val toBeMapped = Either.ofRight<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): OfficeDataConnectorDataTypesExchangeArgs =
        OfficeDataConnectorDataTypesExchangeArgs(
            state = state,
        )
}
